# LPaL 1.0

## A linear programming (LP) problem solver for instructional use

## Solve LPs using the simplex method

## Choose your own entering at each simplex iteration, and see how the tableau changes step-by-step

## Useful for generating in-class and homework assignment LP examples

